# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing that <xmp> elements can be used in place of all <pre>s.

    foo
    bar
      tab-indented
        four-space indented
    baz

    namespace Foo {
        // <length>
        sequence<Foo> foo(DOMString foo);
    };

Name: | justify-self
Value: | auto | normal | stretch
Initial: | auto
Applies to: | block-level boxes, absolutely-positioned boxes, and grid items
Inherited: | no
Percentages: | n/a
Computed value: | specified value
Canonical order: | per grammar
Media: | visual
Animatable: | no

## Index

### Terms defined by this specification

- Foo, in §Unnumbered section
- foo(foo), in §Unnumbered section
- justify-self, in §Unnumbered section

https://drafts.csswg.org/css-values-4/#comb-one Referenced in:

- Unnamed section (2)

https://heycam.github.io/webidl/#idl-DOMString Referenced in:

- Unnamed section

### Terms defined by reference

- [css-values-4] defines the following terms:
  - |
- [WebIDL] defines the following terms:
  - DOMString

## References

### Normative References

[CSS-VALUES-4]
  Tab Atkins Jr.; Elika Etemad. CSS Values and Units Module Level 4. 31 January 2019. WD. URL: https://www.w3.org/TR/css-values-4/
[WebIDL]
  Boris Zbarsky. Web IDL. 15 December 2016. ED. URL: https://heycam.github.io/webidl/

## Property Index

Name | Value | Initial | Applies to | Inh. | %ages | Animatable | Canonical order | Computed value | Media
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
justify-self | auto | normal | stretch | auto | block-level boxes, absolutely-positioned boxes, and grid items | no | n/a | no | per grammar | specified value | visual

## IDL Index

    namespace Foo {
        // <length>
        sequence<Foo> foo(DOMString foo);
    };

#namespacedef-foo Referenced in:

- Unnamed section